/*
    KWin - the KDE window manager
    This file is part of the KDE project.

    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/
#include "logging_p.h"
Q_LOGGING_CATEGORY(LIBKWINEFFECTS, "kwin_effects", QtWarningMsg)
Q_LOGGING_CATEGORY(LIBKWINGLUTILS, "kwin_glutils", QtWarningMsg)
